betty.ancestry.gender.genders module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.gender.genders module

Provide concrete gender implementations.

class betty.ancestry.gender.genders.Female

  Bases: `ShorthandPluginBase`, `Gender`

  A female person.

class betty.ancestry.gender.genders.Male

  Bases: `ShorthandPluginBase`, `Gender`

  A male person.

class betty.ancestry.gender.genders.NonBinary

  Bases: `ShorthandPluginBase`, `Gender`

  A non-binary person.

class betty.ancestry.gender.genders.Unknown

  Bases: `ShorthandPluginBase`, `Gender`

  A person of an unknown gender.